#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.


def test_user_login(login, driver):
    login('user')
    user_dropdown_menu = driver.find_element_by_css_selector(
        '.nav.navbar-nav.navbar-right')
    assert user_dropdown_menu.is_displayed()


def test_admin_login(login, driver):
    login('admin')
    user_dropdown_menu = driver.find_element_by_css_selector(
        '.nav.navbar-nav.navbar-right')
    assert user_dropdown_menu.is_displayed()



# Copyright 2012 United States Government as represented by the
# Administrator of the National Aeronautics and Space Administration.
# All Rights Reserved.
#
# Copyright 2012 Nebula, Inc.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

"""
Template tags for truncating strings.
"""

from django import template

register = template.Library()


@register.filter("truncate")
def truncate(value, size):
    # pylint: disable=chained-comparison
    if len(value) > size and size > 3:
        return value[0:(size - 3)] + '...'
    return value[0:size]
